summaryrefslogtreecommitdiff
path: root/title.bash
diff options
context:
space:
mode:
authorLuke Bratch <luke@bratch.co.uk>2018-08-02 16:07:18 +0100
committerLuke Bratch <luke@bratch.co.uk>2018-08-02 16:07:18 +0100
commitc8d4babad298d6c7e181d187ecef9d31acf407c3 (patch)
tree92af1a063740119a2daf94cfa30f3651baf21b5f /title.bash
parentf6bea3fad5f9b4981e16dae6f7cd99ff288d925a (diff)
Add a quirks mode, starting with claiming to be cURL for YouTube
Diffstat (limited to 'title.bash')
-rwxr-xr-xtitle.bash10
1 files changed, 8 insertions, 2 deletions
diff --git a/title.bash b/title.bash
index 827b0d0..248c52d 100755
--- a/title.bash
+++ b/title.bash
@@ -26,12 +26,18 @@
# v1.3 : add support for Gopher (take first line as title, like text/plain)
# v1.3.1: add a specific interface for cURL to use
# v1.4 : set Accept-Language to en-GB
# v1.5.1: claim a more recent Firefox in the user agent string to make Twitter send the real page title
OPTS='--interface 192.168.122.10 --location --insecure --silent --max-filesize 1048576 --max-time 10 -A "Mozilla/5.0 (X11; Linux x86_64; rv:60.0) Gecko/20100101 Firefox/60.0" -H "Accept-Encoding: gzip" -H "Accept: text/html" -H "Accept-Language: en-GB,en;q=0.5"'
read url
+# Quirks
+if echo "$url" | grep -Eq "^http(s|)://(m.|www.|)(youtube\.com|youtu\.be)/" ; then
+ OPTS='--interface 192.168.122.10 --location --insecure --silent --max-filesize 1048576 --max-time 10 -H "Accept-Encoding: gzip" -H "Accept: text/html" -H "Accept-Language: en-GB,en;q=0.5"'
+fi
+
TIME=$(date +%s%N)
if [ -z "$TIME" ]
@@ -45,7 +51,7 @@ then
echo "Usage: '!title <url>' where <url> is an http:// or https:// URL"
elif [ "$url" == "-v" ] || [ "$url" == "--version" ]
then
- echo "blatitle version 1.4.1"
+ echo "blatitle version 1.5"
else
eval curl $OPTS -D /tmp/$TIME.header '$url' -o /tmp/$TIME.body.gz
ret=$?
@@ -26,12 +26,18 @@
# v1.3.1: add a specific interface for cURL to use
# v1.4 : set Accept-Language to en-GB
-# v1.5.1: claim a more recent Firefox in the user agent string to make Twitter send the real page title
+# v1.4.1: claim a more recent Firefox in the user agent string to make Twitter send the real page title
+# v1.5 : add a quirks mode, starting with claiming to be cURL for YouTube
OPTS='--interface 192.168.122.10 --location --insecure --silent --max-filesize 1048576 --max-time 10 -A "Mozilla/5.0 (X11; Linux x86_64; rv:60.0) Gecko/20100101 Firefox/60.0" -H "Accept-Encoding: gzip" -H "Accept: text/html" -H "Accept-Language: en-GB,en;q=0.5"'
read url